#
#  (C) Tenable Network Security
#


 desc = "
Synopsis :

The remote Windows host contains one or more applications from
Mozilla.org. 

Description :

There is at least one open-source application from Mozilla.org
installed on the remote Windows host. 

See also :

http://www.mozilla.org/products/

Risk factor : 

None";


if (description) {
  script_id(20862);
  script_version("$Revision: 1.5 $");

  script_name(english:"Mozilla.org Application Detection");
  script_summary(english:"Checks for various applications from Mozilla.org"); 
 
  script_description(english:desc);
 
  script_category(ACT_GATHER_INFO);
  script_family(english:"Windows");

  script_copyright(english:"This script is Copyright (C) 2006 Tenable Network Security");

  script_dependencies("smb_hotfixes.nasl");
  script_require_keys("SMB/Registry/Enumerated");
  script_require_ports(139, 445);

  exit(0);
}


include("global_settings.inc");
include("smb_func.inc");


# Connect to the appropriate share.
if (!get_kb_item("SMB/Registry/Enumerated")) exit(0);
name    =  kb_smb_name();
port    =  kb_smb_transport();
if (!get_port_state(port)) exit(0);
login   =  kb_smb_login();
pass    =  kb_smb_password();
domain  =  kb_smb_domain();

soc = open_sock_tcp(port);
if (!soc) exit(0);

session_init(socket:soc, hostname:name);
rc = NetUseAdd(login:login, password:pass, domain:domain, share:"IPC$");
if (rc != 1) {
  NetUseDel();
  exit(0);
}


# Connect to remote registry.
hklm = RegConnectRegistry(hkey:HKEY_LOCAL_MACHINE);
if (isnull(hklm)) {
  if (log_verbosity > 1) debug_print("can't connect to the remote registry!", level:0);
  NetUseDel();
  exit(0);
}


# Determine if various applications are installed.
#
# - Mozilla Browser.
exe = NULL;
key = "SOFTWARE\mozilla.org\Mozilla";
key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h)) {
  item = RegQueryValue(handle:key_h, item:"CurrentVersion");
  if (!isnull(item)) {
    ver = item[1];

    key2 = "SOFTWARE\mozilla.org\Mozilla\" + ver + "\Main";
    key_h2 = RegOpenKey(handle:hklm, key:key2, mode:MAXIMUM_ALLOWED);
    if (!isnull(key_h2)) {
      item = RegQueryValue(handle:key_h2, item:"PathToExe");
      if (!isnull(item)) exe = item[1];
      RegCloseKey(handle:key_h2);
    }
    if ( exe )
    {
     set_kb_item(name:"Mozilla/Version", value:ver);
     info += string(" - Mozilla Browser version ", ver, " is installed as\n   ", exe, "\n\n");
    }
  }
  RegCloseKey(handle:key_h);
}
# - Mozilla Firefox.
exe = NULL;
key = "SOFTWARE\Mozilla\Mozilla Firefox";
key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h)) {
  item = RegQueryValue(handle:key_h, item:"CurrentVersion");
  if (!isnull(item)) {
    ver = item[1];

    key2 = "SOFTWARE\Mozilla\Mozilla Firefox\" + ver + "\Main";
    key_h2 = RegOpenKey(handle:hklm, key:key2, mode:MAXIMUM_ALLOWED);
    if (!isnull(key_h2)) {
      item = RegQueryValue(handle:key_h2, item:"PathToExe");
      if (!isnull(item)) exe = item[1];
      RegCloseKey(handle:key_h2);
    }

    if ( exe )
    {
     set_kb_item(name:"Mozilla/Firefox/Version", value:ver);
     info += string(" - Mozilla Firefox version ", ver, " is installed as\n   ", exe, "\n\n");
    }
  }
  RegCloseKey(handle:key_h);
}
# nb: this is for older versions of Firefox (eg, 0.8).
else {
  key = "SOFTWARE\mozilla.org\Mozilla Firefox";
  key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
  if (!isnull(key_h)) {
    item = RegQueryValue(handle:key_h, item:"CurrentVersion");
    if (!isnull(item)) {
      ver = item[1];

      key2 = "SOFTWARE\mozilla.org\Mozilla Firefox\" + ver + "\Main";
      key_h2 = RegOpenKey(handle:hklm, key:key2, mode:MAXIMUM_ALLOWED);
      if (!isnull(key_h2)) {
        item = RegQueryValue(handle:key_h2, item:"PathToExe");
        if (!isnull(item)) exe = item[1];
        RegCloseKey(handle:key_h2);
      }
      if ( exe )
      {
       set_kb_item(name:"Mozilla/Firefox/Version", value:ver);
       info += string(" - Mozilla Firefox version ", ver, " is installed as\n   ", exe, "\n\n");
      }
    }
    RegCloseKey(handle:key_h);
  }
}
# - Mozilla Thunderbird.
exe = NULL;
key = "SOFTWARE\Mozilla\Mozilla Thunderbird";
key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h)) {
  item = RegQueryValue(handle:key_h, item:"CurrentVersion");
  if (!isnull(item)) {
    ver = item[1];

    key2 = "SOFTWARE\Mozilla\Mozilla Thunderbird\" + ver + "\Main";
    key_h2 = RegOpenKey(handle:hklm, key:key2, mode:MAXIMUM_ALLOWED);
    if (!isnull(key_h2)) {
      item = RegQueryValue(handle:key_h2, item:"PathToExe");
      if (!isnull(item)) exe = item[1];
      RegCloseKey(handle:key_h2);
    }

    if ( exe )
    { 
     set_kb_item(name:"Mozilla/Thunderbird/Version", value:ver);
     info += string(" - Mozilla Thunderbird version ", ver, " is installed as\n   ", exe, "\n\n");
    }
  }
  RegCloseKey(handle:key_h);
}
# - SeaMonkey.
exe = NULL;
key = "SOFTWARE\mozilla.org\SeaMonkey";
key_h = RegOpenKey(handle:hklm, key:key, mode:MAXIMUM_ALLOWED);
if (!isnull(key_h)) {
  item = RegQueryValue(handle:key_h, item:"CurrentVersion");
  if (!isnull(item)) {
    ver = item[1];

    key2 = "SOFTWARE\mozilla.org\SeaMonkey\" + ver + "\Main";
    key_h2 = RegOpenKey(handle:hklm, key:key2, mode:MAXIMUM_ALLOWED);
    if (!isnull(key_h2)) {
      item = RegQueryValue(handle:key_h2, item:"PathToExe");
      if (!isnull(item)) exe = item[1];
      RegCloseKey(handle:key_h2);
    }

    if ( exe )
    {
     set_kb_item(name:"SeaMonkey/Version", value:ver);
     info += string(" - SeaMonkey version ", ver, " is installed as\n   ", exe, "\n\n");
    }
  }
  RegCloseKey(handle:key_h);
}
RegCloseKey(handle:hklm);


if (info) {
  report = string(
    desc,
    "\n\n",
    "Plugin output :\n",
    "\n",
    info
  );

  security_note(port:kb_smb_transport(), data:report);
}


# Clean up.
NetUseDel();
